gettext: Internationalization/localization infrastructure
=========================================================

Description
-----------

The GNU gettext utilities provide a framework to produce multi-lingual messages.


License
-------

GPLV2+
